[![PyPI Version](https://badge.fury.io/py/outputfile.svg)](https://badge.fury.io/py/outputfile)
[![Python Build](https://github.com/nbiotcloud/outputfile/actions/workflows/main.yml/badge.svg)](https://github.com/nbiotcloud/outputfile/actions/workflows/main.yml)
[![Documentation](https://readthedocs.org/projects/outputfile/badge/?version=stable)](https://outputfile.readthedocs.io/en/stable/?badge=stable)
[![Coverage Status](https://coveralls.io/repos/github/nbiotcloud/outputfile/badge.svg?branch=main)](https://coveralls.io/github/nbiotcloud/outputfile?branch=main)
[![python-versions](https://img.shields.io/pypi/pyversions/outputfile.svg)](https://pypi.python.org/pypi/outputfile)

# Timestamp Preserving Output File Writer

* [Documentation](https://outputfile.readthedocs.io/en/stable/)
* [PyPI](https://pypi.org/project/outputfile/)
* [Sources](https://github.com/nbiotcloud/outputfile)
* [Issues](https://github.com/nbiotcloud/outputfile/issues)

## Installation

Installing it is pretty easy:

```bash
pip install outputfile
```
